@@ -534,6 +534,29 @@ def test_timestamp(cnxn):
     assert result == value
 
 
+def test_timestamptz(cnxn):
+    cnxn.execute("create table t1(a timestamptz)")
+    value = datetime(2001, 2, 3, 4, 5, 6, 7)
+    cnxn.execute("insert into t1 values ($1)", value)
+    result = cnxn.fetchval("select a from t1")
+    assert result == value
+
+
+def test_timezone_toutc(cnxn):
+    """
+    Ensure we can pass a datetime as a parameter and convert it to UTC.
+    """
+    # 2020-04-14 17:00 Central -> 2020-04-14 22:00 UTC
+    central = datetime(2020, 4, 14, 17, 0)
+
+    utc = cnxn.fetchval(
+        """
+        select timezone('UTC', $1 at time zone 'America/Chicago')
+        """, central)
+
+    assert utc == datetime(2020, 4, 14, 22, 0)
+
+
 def test_interval(cnxn):
     cnxn.execute("create table t1(a interval)")
     value = timedelta(days=3, hours=4, minutes=5, seconds=6)
@@ -563,6 +586,13 @@ def test_interval(cnxn):
 # array of parameters
 #
 
+def test_array_date(cnxn):
+    cnxn.execute("create table t1(id int, v date[])")
+    value = [None, date(2001, 1, 1), date(2002, 12, 13)]
+    cnxn.execute("insert into t1 values (1, $1)", value)
+    result = cnxn.fetchval("select v from t1")
+    assert result == value
+
 def test_array_int2(cnxn):
     cnxn.execute("create table t1(id int, v int[])")
     value = [None, -32768, -2, -1, 0, 1, 2, 32767]
